pub struct TestHelperMarker;Trait Implementations
Sourceimpl Clone for TestHelperMarker
impl Clone for TestHelperMarker
Sourcefn clone(&self) -> TestHelperMarker
fn clone(&self) -> TestHelperMarker
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TestHelperMarker
impl Debug for TestHelperMarker
Sourceimpl DiscoverableProtocolMarker for TestHelperMarker
impl DiscoverableProtocolMarker for TestHelperMarker
Sourceconst PROTOCOL_NAME: &'static str = <Self as ProtocolMarker>::DEBUG_NAME
const PROTOCOL_NAME: &'static str = <Self as ProtocolMarker>::DEBUG_NAME
The name of the protocol (to be used for service lookup and discovery).
Sourceimpl Hash for TestHelperMarker
impl Hash for TestHelperMarker
Sourceimpl Ord for TestHelperMarker
impl Ord for TestHelperMarker
Sourcefn cmp(&self, other: &TestHelperMarker) -> Ordering
fn cmp(&self, other: &TestHelperMarker) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for TestHelperMarker
impl PartialEq for TestHelperMarker
Sourcefn eq(&self, other: &TestHelperMarker) -> bool
fn eq(&self, other: &TestHelperMarker) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for TestHelperMarker
impl PartialOrd for TestHelperMarker
Sourceimpl ProtocolMarker for TestHelperMarker
impl ProtocolMarker for TestHelperMarker
Sourceconst DEBUG_NAME: &'static str = "fidl.test.dso.TestHelper"
const DEBUG_NAME: &'static str = "fidl.test.dso.TestHelper"
The name of the protocol suitable for debug purposes. Read more
Sourcetype Proxy = TestHelperProxy
type Proxy = TestHelperProxy
The type of the structure against which FIDL requests are made.
Queries made against the proxy are sent to the paired
ServerEnd.Sourcetype RequestStream = TestHelperRequestStream
type RequestStream = TestHelperRequestStream
The type of the stream of requests coming into a server.
Sourcetype SynchronousProxy = TestHelperSynchronousProxy
type SynchronousProxy = TestHelperSynchronousProxy
The type of the structure against which thread-blocking FIDL requests are made.
Queries made against the proxy are sent to the paired
ServerEnd.impl Copy for TestHelperMarker
impl Eq for TestHelperMarker
impl StructuralPartialEq for TestHelperMarker